[![Python package](https://github.com/BASIN-3D/django-basin3d/actions/workflows/main.yml/badge.svg)](https://github.com/BASIN-3D/django-basin3d/actions/workflows/main.yml) 
[![Pypi](https://img.shields.io/pypi/v/django-basin3d)](https://pypi.org/project/django-basin3d/)

# django-basin3d
Django web framework for Broker for Assimilation, Synthesis and Integration of eNvironmental Diverse, Distributed Datasets

## Using django-basin3d
Knowledge of Django is required to use django-basin3d.

See [Django documentation](https://docs.djangoproject.com/) for details on creating a Django app.

### Install
To utilize django-basin3d in a custom app, install the source distribution with pip:

    $ pip install django-basin3d
    
### Example use
See [django-basin3d Example documentation](https://basin3d.readthedocs.io/projects/django-basin3d/en/stable/index.html) for an example of configuring an application to access USGS Daily and Instantaneous Values.

## Change Log
See the [changelog](https://basin3d.readthedocs.io/projects/django-basin3d/en/stable/changelog.html) for a history of updates and changes to django-basin3d.

## Authors
* **Charuleka Varadharajan** - [LBL](http://eesa.lbl.gov/profiles/charuleka-varadharajan/)
* **Valerie Hendrix**  - [LBL](https://crd.lbl.gov/departments/data-science-and-technology/uss/staff/valerie-hendrix)
* **Danielle Svehla Christianson** - [LBL](https://crd.lbl.gov/departments/data-science-and-technology/uss/staff/danielle-christianson/)

## Copyright
Broker for Assimilation, Synthesis and Integration of eNvironmental Diverse, Distributed Datasets (BASIN-3D) Copyright (c) 2019, The
Regents of the University of California, through Lawrence Berkeley National
Laboratory (subject to receipt of any required approvals from the U.S.
Dept. of Energy).  All rights reserved.

If you have questions about your rights to use or distribute this software,
please contact Berkeley Lab's Intellectual Property Office at
IPO@lbl.gov.

NOTICE.  This Software was developed under funding from the U.S. Department
of Energy and the U.S. Government consequently retains certain rights.  As
such, the U.S. Government has been granted for itself and others acting on
its behalf a paid-up, nonexclusive, irrevocable, worldwide license in the
Software to reproduce, distribute copies to the public, prepare derivative
works, and perform publicly and display publicly, and to permit other to do
so.

## License
See [LICENSE](https://basin3d.readthedocs.io/projects/django-basin3d/en/stable/license_agreement.html) file for licensing details

## Acknowledgments
This research is supported as part of the Watershed Function Scientific Focus Area funded by the U.S. Department of Energy, Office of Science, Office of Biological and Environmental Research under Award no. DE-AC02-05CH11231. This research used resources of the National Energy Research Scientific Computing Center (NERSC), U.S. Department of Energy Office of Science User Facility operated under Contract No. DE-AC02-05CH11231. 
